==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/model/MsQueryDeviceResult.java <==
package com.xforceplus.seller.config.client.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * 终端查询结果
 */
@ApiModel(description = "终端查询结果")

@JsonInclude(NON_NULL)
public class MsQueryDeviceResult {
  @JsonProperty("devices")
  private List<MsDeviceInfo> devices = new ArrayList<MsDeviceInfo>();

  @JsonProperty("onlineDeviceIds")
  private List<Long> onlineDeviceIds = new ArrayList<Long>();

  @JsonProperty("onlineDeviceUns")
  private List<String> onlineDeviceUns = new ArrayList();



  @JsonProperty("pageInfo")
  private MsResponsePageInfo pageInfo = null;

  public List<String> getOnlineDeviceUns() {
    return onlineDeviceUns;
  }

  public void setOnlineDeviceUns(List<String> onlineDeviceUns) {
    this.onlineDeviceUns = onlineDeviceUns;
  }


  @JsonIgnore
  public MsQueryDeviceResult devices(List<MsDeviceInfo> devices) {
    this.devices = devices;
    return this;
  }

  public MsQueryDeviceResult addDevicesItem(MsDeviceInfo devicesItem) {
    this.devices.add(devicesItem);
    return this;
  }

   /**
   * 设备列表
   * @return devices
  **/
  @ApiModelProperty(value = "设备列表")
  public List<MsDeviceInfo> getDevices() {
    return devices;
  }

  public void setDevices(List<MsDeviceInfo> devices) {
    this.devices = devices;
  }

  @JsonIgnore
  public MsQueryDeviceResult onlineDeviceIds(List<Long> onlineDeviceIds) {
    this.onlineDeviceIds = onlineDeviceIds;
    return this;
  }

  public MsQueryDeviceResult addOnlineDeviceIdsItem(Long onlineDeviceIdsItem) {
    this.onlineDeviceIds.add(onlineDeviceIdsItem);
    return this;
  }

   /**
   * 在线列表,当查询在线状态参数为true时返回
   * @return onlineDeviceIds
  **/
  @ApiModelProperty(value = "在线列表,当查询在线状态参数为true时返回")
  public List<Long> getOnlineDeviceIds() {
    return onlineDeviceIds;
  }

  public void setOnlineDeviceIds(List<Long> onlineDeviceIds) {
    this.onlineDeviceIds = onlineDeviceIds;
  }

  @JsonIgnore
  public MsQueryDeviceResult pageInfo(MsResponsePageInfo pageInfo) {
    this.pageInfo = pageInfo;
    return this;
  }

   /**
   * 分页信息
   * @return pageInfo
  **/
  @ApiModelProperty(value = "分页信息")
  public MsResponsePageInfo getPageInfo() {
    return pageInfo;
  }

  public void setPageInfo(MsResponsePageInfo pageInfo) {
    this.pageInfo = pageInfo;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsQueryDeviceResult queryDeviceResult = (MsQueryDeviceResult) o;
    return Objects.equals(this.devices, queryDeviceResult.devices) &&
        Objects.equals(this.onlineDeviceIds, queryDeviceResult.onlineDeviceIds) &&
        Objects.equals(this.pageInfo, queryDeviceResult.pageInfo);
  }

  @Override
  public int hashCode() {
    return Objects.hash(devices, onlineDeviceIds, pageInfo);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsQueryDeviceResult {\n");
    
    sb.append("    devices: ").append(toIndentedString(devices)).append("\n");
    sb.append("    onlineDeviceIds: ").append(toIndentedString(onlineDeviceIds)).append("\n");
    sb.append("    pageInfo: ").append(toIndentedString(pageInfo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> seller-config-client-api-4.1.30-20250928.054456-3-sources.jar: com/xforceplus/seller/config/client/model/MsQueryDeviceResult.java <==
package com.xforceplus.seller.config.client.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * 终端查询结果
 */
@ApiModel(description = "终端查询结果")

@JsonInclude(NON_NULL)
public class MsQueryDeviceResult implements Serializable {
  @JsonProperty("devices")
  private List<MsDeviceInfo> devices = new ArrayList<MsDeviceInfo>();

  @JsonProperty("onlineDeviceIds")
  private List<Long> onlineDeviceIds = new ArrayList<Long>();

  @JsonProperty("onlineDeviceUns")
  private List<String> onlineDeviceUns = new ArrayList();



  @JsonProperty("pageInfo")
  private MsResponsePageInfo pageInfo = null;

  public List<String> getOnlineDeviceUns() {
    return onlineDeviceUns;
  }

  public void setOnlineDeviceUns(List<String> onlineDeviceUns) {
    this.onlineDeviceUns = onlineDeviceUns;
  }


  @JsonIgnore
  public MsQueryDeviceResult devices(List<MsDeviceInfo> devices) {
    this.devices = devices;
    return this;
  }

  public MsQueryDeviceResult addDevicesItem(MsDeviceInfo devicesItem) {
    this.devices.add(devicesItem);
    return this;
  }

   /**
   * 设备列表
   * @return devices
  **/
  @ApiModelProperty(value = "设备列表")
  public List<MsDeviceInfo> getDevices() {
    return devices;
  }

  public void setDevices(List<MsDeviceInfo> devices) {
    this.devices = devices;
  }

  @JsonIgnore
  public MsQueryDeviceResult onlineDeviceIds(List<Long> onlineDeviceIds) {
    this.onlineDeviceIds = onlineDeviceIds;
    return this;
  }

  public MsQueryDeviceResult addOnlineDeviceIdsItem(Long onlineDeviceIdsItem) {
    this.onlineDeviceIds.add(onlineDeviceIdsItem);
    return this;
  }

   /**
   * 在线列表,当查询在线状态参数为true时返回
   * @return onlineDeviceIds
  **/
  @ApiModelProperty(value = "在线列表,当查询在线状态参数为true时返回")
  public List<Long> getOnlineDeviceIds() {
    return onlineDeviceIds;
  }

  public void setOnlineDeviceIds(List<Long> onlineDeviceIds) {
    this.onlineDeviceIds = onlineDeviceIds;
  }

  @JsonIgnore
  public MsQueryDeviceResult pageInfo(MsResponsePageInfo pageInfo) {
    this.pageInfo = pageInfo;
    return this;
  }

   /**
   * 分页信息
   * @return pageInfo
  **/
  @ApiModelProperty(value = "分页信息")
  public MsResponsePageInfo getPageInfo() {
    return pageInfo;
  }

  public void setPageInfo(MsResponsePageInfo pageInfo) {
    this.pageInfo = pageInfo;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsQueryDeviceResult queryDeviceResult = (MsQueryDeviceResult) o;
    return Objects.equals(this.devices, queryDeviceResult.devices) &&
        Objects.equals(this.onlineDeviceIds, queryDeviceResult.onlineDeviceIds) &&
        Objects.equals(this.pageInfo, queryDeviceResult.pageInfo);
  }

  @Override
  public int hashCode() {
    return Objects.hash(devices, onlineDeviceIds, pageInfo);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsQueryDeviceResult {\n");
    
    sb.append("    devices: ").append(toIndentedString(devices)).append("\n");
    sb.append("    onlineDeviceIds: ").append(toIndentedString(onlineDeviceIds)).append("\n");
    sb.append("    pageInfo: ").append(toIndentedString(pageInfo)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
